@@ -4,10 +4,10 @@ from toolz import curry
 @curry
 def nth(n, xs):
     """Returns the nth element of the given list or string. If n is negative the
-element at index length + n is returned"""
+    element at index length + n is returned"""
     try:
         return xs[n]
-    except IndexError:
+    except (IndexError, TypeError):
         if type(xs) is str:
             return ""
         return None
